/*
 * File: WordCount.java
 * --------------------
 * Counts the characters, words, and lines in a file.
 */

package demos;

import acm.program.*;
import java.io.*;

@SuppressWarnings("serial")
public class WordCount extends ConsoleProgram {	

	public void run() {
		try {
			int lines = 0;
			int words = 0;
			int chars = 0;
			BufferedReader rd = openInputFile("File: ");
			while (true) {
				String line = rd.readLine();
				if (line == null) break;
				lines++;
				words += countWords(line);
				chars += line.length();
			}
			rd.close();
			println("Lines = " + lines);
			println("Words = " + words);
			println("Chars = " + chars);
		} catch (IOException ex) {
			println("An I/O exception has occurred");
		}
	}
	


/**
 * Asks the user for the name of an input file and returns a BufferedReader
 * attached to its contents. If the file does not exist, the user is given
 * another chance to try.
 */ 
	private BufferedReader openInputFile(String prompt) {
		BufferedReader rd = null;

		while (rd == null) { 
			try { 
				String name = readLine(prompt); 
				rd = new BufferedReader(new FileReader(name)); 
			} catch (IOException ex) {
				println("Can't open that file."); 
			} 
		}
 		return rd;
	}
 	
/**
 * Counts the words (consecutive strings of letters and/or digits) in the input
 * line.
 */ 
	private int countWords(String line) {
		boolean inWord = false;
		int words = 0;
		for (int i = 0; i < line.length(); i++) {
			char ch = line.charAt(i);
			if (Character.isLetterOrDigit(ch)) {
				inWord = true;
			} else {
				if (inWord) words++;
				inWord = false;
			}
		}
		if (inWord) words++;
		return words;
	}
	
}	
	

